==> sslexplorer-0.2.13-src.tar.gz: sslexplorer-0.2.13/sslexplorer-community-tunnels/src/com/sslexplorer/tunnels/TunnelPlugin.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.tunnels;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.sslexplorer.agent.DefaultAgentManager;
import com.sslexplorer.core.CoreMenuTree;
import com.sslexplorer.core.CoreServlet;
import com.sslexplorer.core.CoreUtil;
import com.sslexplorer.core.MenuItem;
import com.sslexplorer.core.PageTaskMenuTree;
import com.sslexplorer.extensions.ExtensionException;
import com.sslexplorer.extensions.types.DefaultPlugin;
import com.sslexplorer.navigation.MenuTree;
import com.sslexplorer.navigation.NavigationManager;
import com.sslexplorer.policyframework.Permission;
import com.sslexplorer.policyframework.PolicyConstants;
import com.sslexplorer.policyframework.PolicyDatabase;
import com.sslexplorer.policyframework.PolicyDatabaseFactory;
import com.sslexplorer.policyframework.PolicyUtil;
import com.sslexplorer.policyframework.ResourceType;
import com.sslexplorer.policyframework.itemactions.AddToFavoritesAction;
import com.sslexplorer.policyframework.itemactions.CloneResourceAction;
import com.sslexplorer.policyframework.itemactions.EditResourceAction;
import com.sslexplorer.policyframework.itemactions.RemoveFromFavoritesAction;
import com.sslexplorer.policyframework.itemactions.RemoveResourceAction;
import com.sslexplorer.security.SessionInfo;
import com.sslexplorer.table.TableItemActionMenuTree;
import com.sslexplorer.tunnels.itemactions.SwitchOffAction;
import com.sslexplorer.tunnels.itemactions.SwitchOnAction;

/**
 * Plugin implementation thats the <i>Network Places</i> feature.
 * 
 * @author James D Robinson <a href="mailto:james@3sp.com">&lt;james@3sp.com&gt;</a>
 */
public class TunnelPlugin extends DefaultPlugin {

    /**
     * Tunnel resource type ID
     */
    public final static int SSL_TUNNEL_RESOURCE_TYPE_ID = 4;

    /**
     * Tunnel resource type
     */
    public static final ResourceType SSL_TUNNEL_RESOURCE_TYPE = new TunnelResourceType();

    /**
     * Extension bundle ID
     */
    public static final String BUNDLE_ID = "sslexplorer-community-tunnels";

    final static Log log = LogFactory.getLog(TunnelPlugin.class);

    /**
     * Message resources key (resource bundle id)
     */
    public static final String MESSAGE_RESOURCES_KEY = "tunnels";

    /**
     * Constructor.
     */
    public TunnelPlugin() {
        super("/WEB-INF/sslexplorer-community-tunnels-tiles-defs.xml", true);
    }

    /* (non-Javadoc)
     * @see com.sslexplorer.extensions.types.DefaultPlugin#activatePlugin()
     */
    public void activatePlugin() throws ExtensionException {
        super.activatePlugin();
        try {
            initDatabase();
            initPolicyFramework();
            initTableItemActions();
            initMainMenu();
            initPageTasks();
            initService();
            CoreUtil.updateEventsTable(TunnelsEventConstants.class);
        } catch (Exception e) {
            throw new ExtensionException(ExtensionException.INTERNAL_ERROR, e, e.getLocalizedMessage());
        }
    }

	void initDatabase() throws Exception {
        TunnelDatabaseFactory.getInstance().open(CoreServlet.getServlet(), this.getPluginDefinition());
    }

    void initPolicyFramework() throws Exception {
        PolicyDatabase pdb = PolicyDatabaseFactory.getInstance();
        // SSL Tunnel
        pdb.registerResourceType(SSL_TUNNEL_RESOURCE_TYPE);
        SSL_TUNNEL_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN);
        SSL_TUNNEL_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_EDIT_AND_ASSIGN);
        SSL_TUNNEL_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_DELETE);
        SSL_TUNNEL_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_ASSIGN);
    }

    void initTableItemActions() throws Exception {
        MenuTree tree = NavigationManager.getMenuTree(TableItemActionMenuTree.MENU_TABLE_ITEM_ACTION_MENU_TREE);
        // Tunnels
        tree.addMenuItem(null, new MenuItem("tunnel", "tunnels", null, 100, false, SessionInfo.ALL_CONTEXTS));
        tree.addMenuItem("tunnel", new AddToFavoritesAction("tunnels"));
        tree.addMenuItem("tunnel", new RemoveFromFavoritesAction("tunnels"));
        tree.addMenuItem("tunnel", new RemoveResourceAction(SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, "tunnels"));
        tree.addMenuItem("tunnel", new EditResourceAction(SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, "tunnels"));
        //tree.addMenuItem("tunnel", new SwitchOnAction());
		tree.addMenuItem("tunnel", new CloneResourceAction(SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, "tunnels"));
        tree.addMenuItem("tunnel", new SwitchOffAction());
    }

    void initMainMenu() throws Exception {
        MenuTree tree = NavigationManager.getMenuTree(CoreMenuTree.MENU_ITEM_MENU_TREE);

        tree.addMenuItem("resources", new MenuItem("userTunnels", "tunnels", "/showUserTunnels.do", 500, true, null,
                        SessionInfo.USER_CONSOLE_CONTEXT, null, null, SSL_TUNNEL_RESOURCE_TYPE));

        tree.addMenuItem("globalResources", new MenuItem("tunnels", "tunnels", "/showTunnels.do", 400, true, null,
                        SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, SSL_TUNNEL_RESOURCE_TYPE, new Permission[] {
                                        PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN, PolicyConstants.PERM_EDIT_AND_ASSIGN,
                                        PolicyConstants.PERM_DELETE, PolicyConstants.PERM_ASSIGN }) {
            public boolean isAvailable(int checkNavigationContext, SessionInfo info, HttpServletRequest request) {
                boolean available = super.isAvailable(checkNavigationContext, info, request);
                if (available) {
                    try {
                        PolicyUtil.checkPermissions(SSL_TUNNEL_RESOURCE_TYPE, new Permission[] {
                                        PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN, PolicyConstants.PERM_EDIT_AND_ASSIGN,
                                        PolicyConstants.PERM_DELETE, PolicyConstants.PERM_ASSIGN }, request);
                        available = true;
                    } catch (Exception e1) {
                        available = false;
                    }
                }
                return available;
            }
        });
    }

    void initPageTasks() throws Exception {
        MenuTree tree = NavigationManager.getMenuTree(PageTaskMenuTree.PAGE_TASK_MENU_TREE);

        // Tunnels showTunnels
        tree.addMenuItem(null, new MenuItem("showTunnels", null, null, 100, false, SessionInfo.MANAGEMENT_CONSOLE_CONTEXT));
        tree.addMenuItem("showTunnels", new MenuItem("createTunnel", "tunnels", "/defaultTunnelDetails.do", 100, true, "_self",
                        SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, SSL_TUNNEL_RESOURCE_TYPE,
                        new Permission[] { PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN }));
    }

    void initService() throws Exception{
        DefaultAgentManager.getInstance().registerService(TunnelingService.class);
    }
    
    public void stopPlugin() throws ExtensionException {
        super.stopPlugin();
        try {
            stopDatabase();
            stopPolicyFramework();
            removeTableItemActions();
            removeMainMenu();
            removePageTasks();
            stopService();
        } catch (Exception e) {
            throw new ExtensionException(ExtensionException.INTERNAL_ERROR, e);
        }
    }

    private void stopService() {
        DefaultAgentManager.getInstance().unregisterService(TunnelingService.class);
    }

    private void removePageTasks() {
        MenuTree tree = NavigationManager.getMenuTree(PageTaskMenuTree.PAGE_TASK_MENU_TREE);
        tree.removeMenuItem("showTunnels", "createTunnel");
    }

    private void removeMainMenu() {
        MenuTree tree = NavigationManager.getMenuTree(CoreMenuTree.MENU_ITEM_MENU_TREE);
        tree.removeMenuItem("resources", "userTunnels");
        tree.removeMenuItem("globalResources", "tunnels");
    }

    private void removeTableItemActions() {
        MenuTree tree = NavigationManager.getMenuTree(TableItemActionMenuTree.MENU_TABLE_ITEM_ACTION_MENU_TREE);
        tree.removeMenuItem("tunnel", AddToFavoritesAction.TABLE_ITEM_ACTION_ID);
        tree.removeMenuItem("tunnel", RemoveFromFavoritesAction.TABLE_ITEM_ACTION_ID);
        tree.removeMenuItem("tunnel", RemoveResourceAction.TABLE_ITEM_ACTION_ID);
        tree.removeMenuItem("tunnel", EditResourceAction.TABLE_ITEM_ACTION_ID);
        tree.removeMenuItem("tunnel", SwitchOnAction.TABLE_ITEM_ACTION_ID);
        tree.removeMenuItem("tunnel", SwitchOffAction.TABLE_ITEM_ACTION_ID);
    }

    private void stopPolicyFramework() throws Exception {
        PolicyDatabase pdb = PolicyDatabaseFactory.getInstance();
        pdb.deregisterResourceType(SSL_TUNNEL_RESOURCE_TYPE);
    }

    private void stopDatabase() throws Exception {
        TunnelDatabaseFactory.getInstance().close();
    }

}

==> sslexplorer-0.2.15_01-src.tar.gz: sslexplorer-0.2.15_01/sslexplorer-community-tunnels/src/com/sslexplorer/tunnels/TunnelPlugin.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.tunnels;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.sslexplorer.agent.DefaultAgentManager;
import com.sslexplorer.core.CoreMenuTree;
import com.sslexplorer.core.CoreServlet;
import com.sslexplorer.core.CoreUtil;
import com.sslexplorer.core.MenuItem;
import com.sslexplorer.core.PageTaskMenuTree;
import com.sslexplorer.extensions.ExtensionException;
import com.sslexplorer.extensions.types.DefaultPlugin;
import com.sslexplorer.navigation.MenuTree;
import com.sslexplorer.navigation.NavigationManager;
import com.sslexplorer.policyframework.Permission;
import com.sslexplorer.policyframework.PolicyConstants;
import com.sslexplorer.policyframework.PolicyDatabase;
import com.sslexplorer.policyframework.PolicyDatabaseFactory;
import com.sslexplorer.policyframework.PolicyUtil;
import com.sslexplorer.policyframework.ResourceType;
import com.sslexplorer.policyframework.itemactions.AddToFavoritesAction;
import com.sslexplorer.policyframework.itemactions.CloneResourceAction;
import com.sslexplorer.policyframework.itemactions.EditResourceAction;
import com.sslexplorer.policyframework.itemactions.RemoveFromFavoritesAction;
import com.sslexplorer.policyframework.itemactions.RemoveResourceAction;
import com.sslexplorer.security.SessionInfo;
import com.sslexplorer.table.TableItemActionMenuTree;
import com.sslexplorer.tunnels.itemactions.SwitchOffAction;
import com.sslexplorer.tunnels.itemactions.SwitchOnAction;

/**
 * Plugin implementation thats the <i>Network Places</i> feature.
 * 
 * @author James D Robinson <a href="mailto:james@3sp.com">&lt;james@3sp.com&gt;</a>
 */
public class TunnelPlugin extends DefaultPlugin {

    /**
     * Tunnel resource type ID
     */
    public final static int SSL_TUNNEL_RESOURCE_TYPE_ID = 4;

    /**
     * Tunnel resource type
     */
    public static final ResourceType SSL_TUNNEL_RESOURCE_TYPE = new TunnelResourceType();

    /**
     * Extension bundle ID
     */
    public static final String BUNDLE_ID = "sslexplorer-community-tunnels";

    final static Log log = LogFactory.getLog(TunnelPlugin.class);

    /**
     * Message resources key (resource bundle id)
     */
    public static final String MESSAGE_RESOURCES_KEY = "tunnels";

    /**
     * Constructor.
     */
    public TunnelPlugin() {
        super("/WEB-INF/sslexplorer-community-tunnels-tiles-defs.xml", true);
    }

    /* (non-Javadoc)
     * @see com.sslexplorer.extensions.types.DefaultPlugin#activatePlugin()
     */
    public void activatePlugin() throws ExtensionException {
        super.activatePlugin();
        try {
            initDatabase();
            initPolicyFramework();
            initTableItemActions();
            initMainMenu();
            initPageTasks();
            initService();
            CoreUtil.updateEventsTable(TunnelPlugin.MESSAGE_RESOURCES_KEY, TunnelsEventConstants.class);
        } catch (Exception e) {
            throw new ExtensionException(ExtensionException.INTERNAL_ERROR, e, e.getLocalizedMessage());
        }
    }

	void initDatabase() throws Exception {
        TunnelDatabaseFactory.getInstance().open(CoreServlet.getServlet(), this.getPluginDefinition());
    }

    void initPolicyFramework() throws Exception {
        PolicyDatabase pdb = PolicyDatabaseFactory.getInstance();
        // SSL Tunnel
        pdb.registerResourceType(SSL_TUNNEL_RESOURCE_TYPE);
        SSL_TUNNEL_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN);
        SSL_TUNNEL_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_EDIT_AND_ASSIGN);
        SSL_TUNNEL_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_DELETE);
        SSL_TUNNEL_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_ASSIGN);
    }

    void initTableItemActions() throws Exception {
        MenuTree tree = NavigationManager.getMenuTree(TableItemActionMenuTree.MENU_TABLE_ITEM_ACTION_MENU_TREE);
        // Tunnels
        tree.addMenuItem(null, new MenuItem("tunnel", "tunnels", null, 100, false, SessionInfo.ALL_CONTEXTS));
        tree.addMenuItem("tunnel", new AddToFavoritesAction("tunnels"));
        tree.addMenuItem("tunnel", new RemoveFromFavoritesAction("tunnels"));
        tree.addMenuItem("tunnel", new RemoveResourceAction(SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, "tunnels"));
        tree.addMenuItem("tunnel", new EditResourceAction(SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, "tunnels"));
        //tree.addMenuItem("tunnel", new SwitchOnAction());
		tree.addMenuItem("tunnel", new CloneResourceAction(SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, "tunnels"));
        tree.addMenuItem("tunnel", new SwitchOffAction());
    }

    void initMainMenu() throws Exception {
        MenuTree tree = NavigationManager.getMenuTree(CoreMenuTree.MENU_ITEM_MENU_TREE);

        tree.addMenuItem("resources", new MenuItem("userTunnels", "tunnels", "/showUserTunnels.do", 500, true, null,
                        SessionInfo.USER_CONSOLE_CONTEXT, null, null, SSL_TUNNEL_RESOURCE_TYPE));

        tree.addMenuItem("globalResources", new MenuItem("tunnels", "tunnels", "/showTunnels.do", 400, true, null,
                        SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, SSL_TUNNEL_RESOURCE_TYPE, new Permission[] {
                                        PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN, PolicyConstants.PERM_EDIT_AND_ASSIGN,
                                        PolicyConstants.PERM_DELETE, PolicyConstants.PERM_ASSIGN }) {
            public boolean isAvailable(int checkNavigationContext, SessionInfo info, HttpServletRequest request) {
                boolean available = super.isAvailable(checkNavigationContext, info, request);
                if (available) {
                    try {
                        PolicyUtil.checkPermissions(SSL_TUNNEL_RESOURCE_TYPE, new Permission[] {
                                        PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN, PolicyConstants.PERM_EDIT_AND_ASSIGN,
                                        PolicyConstants.PERM_DELETE, PolicyConstants.PERM_ASSIGN }, request);
                        available = true;
                    } catch (Exception e1) {
                        available = false;
                    }
                }
                return available;
            }
        });
    }

    void initPageTasks() throws Exception {
        MenuTree tree = NavigationManager.getMenuTree(PageTaskMenuTree.PAGE_TASK_MENU_TREE);

        // Tunnels showTunnels
        tree.addMenuItem(null, new MenuItem("showTunnels", null, null, 100, false, SessionInfo.MANAGEMENT_CONSOLE_CONTEXT));
        tree.addMenuItem("showTunnels", new MenuItem("createTunnel", "tunnels", "/defaultTunnelDetails.do", 100, true, "_self",
                        SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, SSL_TUNNEL_RESOURCE_TYPE,
                        new Permission[] { PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN }));
    }

    void initService() throws Exception{
        DefaultAgentManager.getInstance().registerService(TunnelingService.class);
    }
    
    public void stopPlugin() throws ExtensionException {
        super.stopPlugin();
        try {
            stopDatabase();
            stopPolicyFramework();
            removeTableItemActions();
            removeMainMenu();
            removePageTasks();
            stopService();
        } catch (Exception e) {
            throw new ExtensionException(ExtensionException.INTERNAL_ERROR, e);
        }
    }

    private void stopService() {
        DefaultAgentManager.getInstance().unregisterService(TunnelingService.class);
    }

    private void removePageTasks() {
        MenuTree tree = NavigationManager.getMenuTree(PageTaskMenuTree.PAGE_TASK_MENU_TREE);
        tree.removeMenuItem("showTunnels", "createTunnel");
    }

    private void removeMainMenu() {
        MenuTree tree = NavigationManager.getMenuTree(CoreMenuTree.MENU_ITEM_MENU_TREE);
        tree.removeMenuItem("resources", "userTunnels");
        tree.removeMenuItem("globalResources", "tunnels");
    }

    private void removeTableItemActions() {
        MenuTree tree = NavigationManager.getMenuTree(TableItemActionMenuTree.MENU_TABLE_ITEM_ACTION_MENU_TREE);
        tree.removeMenuItem("tunnel", AddToFavoritesAction.TABLE_ITEM_ACTION_ID);
        tree.removeMenuItem("tunnel", RemoveFromFavoritesAction.TABLE_ITEM_ACTION_ID);
        tree.removeMenuItem("tunnel", RemoveResourceAction.TABLE_ITEM_ACTION_ID);
        tree.removeMenuItem("tunnel", EditResourceAction.TABLE_ITEM_ACTION_ID);
        tree.removeMenuItem("tunnel", SwitchOnAction.TABLE_ITEM_ACTION_ID);
        tree.removeMenuItem("tunnel", SwitchOffAction.TABLE_ITEM_ACTION_ID);
    }

    private void stopPolicyFramework() throws Exception {
        PolicyDatabase pdb = PolicyDatabaseFactory.getInstance();
        pdb.deregisterResourceType(SSL_TUNNEL_RESOURCE_TYPE);
    }

    private void stopDatabase() throws Exception {
        TunnelDatabaseFactory.getInstance().close();
    }

}
